@@ -6,14 +6,15 @@ import json
 
 class Serial(object):
     
-    def __init__(self, port, baudrate, timeout=1, parent=None):
+    def __init__(self, port, baudrate, timeout=1, identity="UC2_Feather", parent=None):
         self.serialport = port
         self.baudrate = baudrate
         self.timeout = timeout
         self._parent = parent
+        self.identity = identity
         
         self.NumberRetryReconnect = 0
-        self.MaxNumberRetryReconnect = 20
+        self.MaxNumberRetryReconnect = 3
         
         self.open() # creates self.serialdevice
         
@@ -64,7 +65,7 @@ class Serial(object):
         """Check if the firmware is correct"""
         path = "/state_get"
         _state = self.post_json(path, {"task":path}, timeout=timeout)
-        if _state["identifier_name"] == "UC2_Feather": 
+        if _state["identifier_name"] == self.identity: 
             return True
         else: return False
 
@@ -106,9 +107,11 @@ class Serial(object):
         """Write JSON document to serial device"""
         try:
             if self.serialport == "NotConnected" and self.NumberRetryReconnect<self.MaxNumberRetryReconnect:
-                # try to reconnect               
-                self.open()
+                # try to reconnect       
+                self._parent.logger.debug("Trying to reconnect to serial device: "+str(self.NumberRetryReconnect))       
                 self.NumberRetryReconnect += 1
+                self.open()
+                
             self.serialdevice.flushInput()
             self.serialdevice.flushOutput()
         except Exception as e:
@@ -141,7 +144,7 @@ class Serial(object):
             while is_blocking:
                 try:
                     rmessage =  self.serialdevice.readline().decode()
-                    #self._parent.logger.debug(rmessage)
+                    self._parent.logger.debug(rmessage)
                     returnmessage += rmessage
                     if rmessage.find("--")==0:
                         break
@@ -151,12 +154,14 @@ class Serial(object):
                     break
             # casting to dict
             try:
-                returnmessage = json.loads(returnmessage.split("--")[0].split("++")[-1])
+                # TODO: check if this is a valid JSON
+                returnmessage = returnmessage.split("\n--")[0].split("\n++")[-1].replace("\r","").replace("\n", "").replace("'", '"')
+                self._parent.logger.debug(returnmessage)
+                returnmessage = json.loads(returnmessage)
             except:
                 self._parent.logger.debug("Casting json string from serial to Python dict failed")
-                returnmessage = ""
+                returnmessage = None
         return returnmessage
-
         
 class SerialDummy(object):
         
